package de.intevation.flys.client.shared.model;

/**
 * The artifact description describes a state of an artifact. There are
 * operations defined that return former inserted data, possible input values
 * and output targets that are available in the current state of the artifact.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public interface ArtifactDescription {

    /**
     * Returns the data that have been inserted in former states of the
     * artifact.
     *
     * @return the old data of former states.
     */
    public Data[] getOldData();


    /**
     * Returns the data with all its options that might be inserted in the
     * current state of the artifact.
     *
     * @return the current data.
     */
    public Data getCurrentData();


    /**
     * Returns the current state as string.
     *
     * @return the current state.
     */
    public String getCurrentState();


    /**
     * Returns the reachable states as string.
     *
     * @return the reachable states.
     */
    public String[] getReachableStates();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
